@@ -90,6 +90,8 @@ class ChatFullInfo(Chat):
     """*Optional*. The most recent pinned message (by sending date)"""
     permissions: Optional[ChatPermissions] = None
     """*Optional*. Default chat member permissions, for groups and supergroups"""
+    can_send_gift: Optional[bool] = None
+    """*Optional*. :code:`True`, if gifts can be sent to the chat"""
     can_send_paid_media: Optional[bool] = None
     """*Optional*. :code:`True`, if paid media messages can be sent or forwarded to the channel chat. The field is available only for channel chats."""
     slow_mode_delay: Optional[int] = None
@@ -157,6 +159,7 @@ class ChatFullInfo(Chat):
             invite_link: Optional[str] = None,
             pinned_message: Optional[Message] = None,
             permissions: Optional[ChatPermissions] = None,
+            can_send_gift: Optional[bool] = None,
             can_send_paid_media: Optional[bool] = None,
             slow_mode_delay: Optional[int] = None,
             unrestrict_boost_count: Optional[int] = None,
@@ -208,6 +211,7 @@ class ChatFullInfo(Chat):
                 invite_link=invite_link,
                 pinned_message=pinned_message,
                 permissions=permissions,
+                can_send_gift=can_send_gift,
                 can_send_paid_media=can_send_paid_media,
                 slow_mode_delay=slow_mode_delay,
                 unrestrict_boost_count=unrestrict_boost_count,
